@@ -14,3 +14,11 @@ def assert_that(value, matcher):
     mismatch_output = []
     if not matcher.matches(value, mismatch_output):
         raise AssertionError("Expected: %s\nbut: %s" % (matcher, ''.join(mismatch_output)))
+
+class ValueObject(object):
+    def __init__(self, attributes):
+        for key in attributes:
+            setattr(self, key, attributes[key])
+
+def value_object(**kwargs):
+    return ValueObject(kwargs)
